# -*- coding: utf-8 -*-
"""
$Id: Install.py,v 1.3 2005/10/23 21:23:04 roeder Exp $
"""
__author__  = 'Jerome Sandarnaud'
__docformat__ = 'restructuredtext'

# Python imports
from StringIO import StringIO

# CMF imports
from Products.CMFCore.WorkflowTool import addWorkflowFactory
from Products.CMFCore.utils import getToolByName

# Archetypes
from Products.Archetypes.Extensions.utils import installTypes, install_subskin
from Products.Archetypes.public import listTypes

# Product import
from Products.SimpleForum.config import *
from Products.SimpleForum.Extensions.installWorkflows import createSimpleforum_workflow, createSimplepost_workflow
from Products.SimpleForum import permissions


def addWorkflow(self, wf_id, wf_title, method, portal_types):
    """
    add a workflow to portal_workflow
    """
    wtool = getToolByName(self, 'portal_workflow')
    addWorkflowFactory(method,
                       id=wf_id,
                       title=wf_title)
    wtool.manage_addWorkflow('%s (%s)' % (wf_id, wf_title), wf_id)
    wtool.setChainForPortalTypes(portal_types, wf_id)

def setupWorkflows(self, out):
    """
    Install SimpleForum Workflows
    SimpleForum and SimpleForumPost objects have their own workflows
    """
    wtool = getToolByName(self, 'portal_workflow')
    addWorkflow(self, 
                wf_id='simpleforum_workflow',
                wf_title='Simple Forum workflow',
                method=createSimpleforum_workflow,
                portal_types=('SimpleForum',))
                
    addWorkflow(self,
                wf_id='simpleforumpost_workflow',
                wf_title='Simple Forum Post workflow',
                method=createSimplepost_workflow,
                portal_types=('SimpleForumPost',))
                
    wtool.updateRoleMappings()
    print >> out, 'Workflow installed'


def registerTypesForFactory(self, out, types):
    """
    Register types with portal_factory
    """
    factory = getToolByName(self, 'portal_factory')
    registered = factory.getFactoryTypes().keys()
    for type in types:
        if type not in registered:
            registered.append(type)
    factory.manage_setPortalFactoryTypes(listOfTypeIds = registered)
    print >> out, "Registered new types to portal_factory"


def install(self):
    """Install PloneSimpleForum product"""
    out = StringIO()
    # Install types and "switch" external methods
    typeInfo = listTypes(PROJECTNAME)
    installTypes(self, out, typeInfo, PROJECTNAME)
    
    # Install skin
    install_subskin(self, out, GLOBALS)
    
    # Permissions for Plone roles
    self.manage_permission(permissions.AddSimpleForumPost, ('Member', 'Owner', 'Manager'), 1)
    
    # Add workflows
    setupWorkflows(self, out)
    
    # Register Post type w/ portal_factory
    registerTypesForFactory(self, out, ('SimpleForumPost',))
    
    provider = getToolByName(self, 'portal_selenium', None)
    if provider:
        # Functional Tests
        action = {'id':PROJECTNAME.lower(),
                  'name':PROJECTNAME,
                  'action':'string:here/get_%s_ftests'%PROJECTNAME.lower(),
                  'condition': '',
                  'permission': 'View',
                  'category':'ftests',
                  'visible': 1}
        provider.addAction(**action)

    typesTool = getToolByName(self, 'portal_types')
    # Set the human readable title explicitly
    t = getattr(typesTool, 'SimpleForum', None)
    if t:
        t.title = 'Forum'

    out.write('Installation completed.\n')
    return out.getvalue()

def uninstall(self):
    """Uninstall PloneGlossary product"""
    out = StringIO()
    out.write('Uninstallation completed.\n')
    return out.getvalue()
