# -*- coding: utf-8 -*-
"""
$Id: SimpleForumCatalog.py,v 1.1 2005/10/04 13:08:57 kayeva Exp $
"""

__author__  = 'Jerome Sandarnaud'
__docformat__ = 'restructuredtext'

# Zope imports
from Globals import InitializeClass
from AccessControl import ClassSecurityInfo
from Products.ZCatalog.ZCatalog import ZCatalog

# CMF imports
from Products.CMFCore.utils import UniqueObject, getToolByName
from Products.CMFCore import CMFCorePermissions

# Archetypes imports
from Products.Archetypes.public import *
from Products.Archetypes.ReferenceEngine import ReferenceResolver

# Products imports
from Products.SimpleForum.config import *

class SimpleForumCatalog(ZCatalog):
    """Catalog for PloneSimpleForum"""

    id = SIMPLEFORUM_CATALOG
    title = "Forum Catalog"
    
    security = ClassSecurityInfo()
    
    def __init__(self):
        ZCatalog.__init__(self, self.getId())
        
        # Build catalog
        self._initIndexes()

    def _initIndexes(self):
        """Init indexes and metadata of catalog"""
        
        for index_name, index_type in self.enumerateIndexes():
            try: #ugly try catch XXX FIXME
                if index_name not in self.indexes():
                    self.addIndex(index_name, index_type, extra=None)
                if not index_name in self.schema():
                    self.addColumn(index_name)
            except:
                pass
    
    security.declarePublic('enumerateIndexes')
    def enumerateIndexes(self):
        """Returns indexes used by catalog"""
        return (
                ('UID', 'FieldIndex'),
                ('id', 'FieldIndex'),
                ('Title', 'TextIndex'),
                ('getLevel', 'FieldIndex'),
                ('created', 'DateIndex'),
                ('modified', 'DateIndex'),
                ('getPost_author', 'FieldIndex'),
                )
    
    def __url(self, object):
        """Returns url of object"""
        return '/'.join(object.getPhysicalPath())
    
    security.declarePrivate('indexObject')
    def indexObject(self, object):
        '''Add to catalog.'''
        url = self.__url(object)
        self.catalog_object(object, url)

    security.declarePrivate('unindexObject')
    def unindexObject(self, object):
        '''Remove from catalog.'''
        url = self.__url(object)
        self.uncatalog_object(url)

    security.declarePrivate('reindexObject')
    def reindexObject(self, object, idxs=[]):
        """Update catalog after object data has changed.
        The optional idxs argument is a list of specific indexes
        to update (all of them by default).
        """
        url = self.__url(object)
        if idxs != []:
            # Filter out invalid indexes.
            valid_indexes = self._catalog.indexes.keys()
            idxs = [i for i in idxs if i in valid_indexes]
        self.catalog_object(object, url, idxs=idxs)

InitializeClass(SimpleForumCatalog)

def manage_addSimpleForumCatalog(self, REQUEST=None):
    """Add the forum catalog"""
    c = SimpleForumCatalog()
    self._setObject(c.getId(), c)

    if REQUEST is not None:
        return self.manage_main(self, REQUEST,update_menu=1)
