# -*- coding: utf-8 -*-
"""
$Id: Forum.py,v 1.5 2005/10/25 09:42:25 kayeva Exp $
"""
__author__  = 'Jerome Sandarnaud'
__docformat__ = 'restructuredtext'

# Zope imports
from AccessControl import ClassSecurityInfo
from Globals import InitializeClass

# CMF imports
from Products.CMFCore import CMFCorePermissions
from Products.CMFCore.utils  import getToolByName

# Archetypes imports
from Products.Archetypes.public import *

# Products imports
from Products.SimpleForum.config import *
from Products.SimpleForum.SimpleForumCatalog import SimpleForumCatalog, manage_addSimpleForumCatalog
from Products.SimpleForum.content.schemata import SimpleForumSchema as schema

class SimpleForum(BaseBTreeFolder):
    """PloneSimpleForum container"""
    
    portal_type = meta_type = 'SimpleForum'
    archetype_name = 'Forum'
    immediate_view = 'simple_forum_view'
    default_view   = 'simple_forum_view'
    global_allow = True
    filter_content_types = True
    allowed_content_types = ('SimpleForumPost',)
    content_icon = 'simpleforum_icon.gif'

    _at_rename_after_creation = True # rename object according to the title?
        
    schema =  schema
    security = ClassSecurityInfo()
    
    __level = 0

    actions = (
        {
        'id'            : 'view',
        'name'          : 'View',
        'action'        : 'string:${object_url}/simple_forum_view',
        'permissions'   : (CMFCorePermissions.View, ),
        'category'      : 'object',
        'visible'       : 1,
        },)
        
    security.declareProtected('View', 'getLevel')
    def getLevel(self):
        """
        return object depth
        """
        return self.__level
        
    ######################
    # Catalog support
    ######################
  
    def _initCatalog(self):
        """Add forum catalog"""
        
        if not hasattr(self, SIMPLEFORUM_CATALOG):
            add_catalog = manage_addSimpleForumCatalog
            add_catalog(self)
        
        catalog = getattr(self, SIMPLEFORUM_CATALOG)
        catalog.manage_reindexIndex()
        return catalog
    
    security.declarePrivate('manage_afterAdd')
    def manage_afterAdd(self, item, container):
        BaseBTreeFolder.manage_afterAdd(self, item, container)
        # Add catalog
        self._initCatalog()

    security.declareProtected('View', 'getCatalog')
    def getCatalog(self):
        """Returns catalog of Forum"""
        
        if not hasattr(self, SIMPLEFORUM_CATALOG):
            # Build catalog if it doesn't exist
            catalog = self._initCatalog()
        
        catalog = getattr(self, SIMPLEFORUM_CATALOG)
        utool = getToolByName(self, 'portal_url')
        return self.restrictedTraverse(utool.getRelativeContentURL(catalog))
        
    security.declareProtected('View', 'searchResults')
    def searchResults(self, **search_args):
        """
        Return brains from this forum.
        search_args use index of forum_catalog
        """
        cat = self.getCatalog()
        base_path = '/'.join(self.getPhysicalPath())
        return cat.searchResults(path=base_path, portal_type='SimpleForumPost', **search_args)
        
    #########################
    # forum methods
    #########################
    
    
    
    
    
    
registerType(SimpleForum, PROJECTNAME)
