# -*- coding: utf-8 -*-
"""
$Id: Post.py,v 1.8 2005/10/25 09:42:25 kayeva Exp $
"""
__author__  = 'Jerome Sandarnaud'
__docformat__ = 'restructuredtext'

# Python imports
from AccessControl import ClassSecurityInfo
from Acquisition import aq_parent
import string

# CMF imports
from Products.CMFCore  import CMFCorePermissions
from Products.CMFCore.utils import getToolByName

# Archetypes imports
from Products.Archetypes.public import *

# Products imports
from Products.SimpleForum.config import *
from Products.SimpleForum.content.schemata import SimpleForumPostSchema as schema

class SimpleForumPost(BaseFolder):
    """PloneSimplePost """
    
    portal_type = meta_type = 'SimpleForumPost'
    archetype_name = 'Post'
    content_icon = 'simpleforumpost_icon.gif'
    immediate_view = 'simple_post_view'
    default_view   = 'simple_post_view'
    global_allow = False
    filter_content_types = True
    allowed_content_types = ('SimpleForumPost',)

    content_icon = 'simpleforumpost_icon.gif'

    _at_rename_after_creation = False # rename object according to the title?
    
    schema =  schema
    security = ClassSecurityInfo()

    actions = (
        {
        'id'            : 'view',
        'name'          : 'View',
        'action'        : 'string:${object_url}/simple_post_view',
        'permissions'   : (CMFCorePermissions.View, ),
        'category'      : 'object',
        'visible'       : 1,
        },)
      
    security.declarePrivate('_getDefaultLevel')
    def _getDefaultLevel(self):
        """
        set default level to post, parent level + 1
        """
        return aq_parent(self).getLevel() + 1

    security.declarePrivate('_getDefaultPostAuthor')
    def _getDefaultPostAuthor(self):
        """
        TODO
        """
        mtool = getToolByName(self, 'portal_membership')
        member = mtool.getAuthenticatedMember()
        if member is not None:
            return member.getProperty('fullname') or member.getUserName()
        else:
            return "Anonymous User"

    security.declareProtected('View', 'getNumberOfPostsInside')
    def getNumberOfPostsInside(self):
        """
        Get the number of posts/replies within the post.
        
        For displaying purpose.
        """

        cat = getToolByName(self, 'portal_catalog')
        post_path = string.join(self.getPhysicalPath(), '/')
        nb = len(cat(path = post_path))
        return nb


    ##########################
    # Catalog support
    ##########################
    
    security.declareProtected(CMFCorePermissions.ModifyPortalContent, 'indexObject')
    def indexObject(self):
        """Index object in portal catalog and forum catalog"""
        BaseFolder.indexObject(self)
        cat = self.getCatalog()
        cat.indexObject(self)
    
    security.declareProtected(CMFCorePermissions.ModifyPortalContent, 'unindexObject')
    def unindexObject(self):
        """Unindex object in portal catalog and forum catalog"""
        BaseFolder.unindexObject(self)
        cat = self.getCatalog()
        cat.unindexObject(self)
    
    security.declareProtected(CMFCorePermissions.ModifyPortalContent, 'reindexObject')
    def reindexObject(self, idxs=[]):
        """Reindex object in portal catalog and forum catalog"""
        BaseFolder.reindexObject(self, idxs)
        cat = self.getCatalog()
        cat.reindexObject(self, idxs)

registerType(SimpleForumPost, PROJECTNAME)
